@@ -1,16 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-/*
- *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
+/* gweather-prefs.c - Preference handling functions
  *
- *  This code released under the GNU GPL.
- *  Read the file COPYING for more information.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- *  Preference handling functions.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #ifdef HAVE__NL_MEASUREMENT_MEASUREMENT
@@ -19,8 +26,9 @@
 
 #include <glib/gi18n-lib.h>
 #include <gconf/gconf-client.h>
+
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#include <libgweather/gweather-prefs.h>
+#include "gweather-prefs.h"
 
 static GConfEnumStringPair temp_unit_enum_map [] = {
     { TEMP_UNIT_DEFAULT,    N_("Default") },
